using WorkFlowCheck.Common.DTO;


namespace WorkFlowCheck.BL.Services.Interfaces
{
    public interface ISyncService
    {
        Task<List<CheckPointDTO>> GetAllCheckPointAsync();
        Task<CheckPointDTO> GetCheckPointAsync(int id);
        Task<CheckPointDTO> UpdateCheckPointAsync(CheckPointDTO checkPointDTO);
        Task<List<LocationDTO>> GetAllLocationAsync();
        Task<List<EquipmentDTO>> GetAllEquipmentAsync();

        Task<List<CheckListTemplateHeaderDTO>> GetAllCheckListTemplateAsync();
    }
}
